@@ -1,6 +1,6 @@
 #!perl -w
 #
-# $Id: exe_wrap.pl,v 1.22 2004/01/02 20:07:26 epaepa Exp $
+# $Id: exe_wrap.pl,v 1.27 2004/02/01 21:45:29 epaepa Exp $
 # This is a quick XMLTV shell routing to use with the windows exe
 #
 # A single EXE is needed to allow sharing of modules and dlls of all the
@@ -20,6 +20,24 @@ use Carp;
 
 $Carp::MaxEvalLen=40; # limit confess output
 
+# Check for error of running from 'Run' dialogue box with redirection,
+# which Run doesn't understand,
+#
+if (grep /[<>|]/, @ARGV) {
+    warn <<END
+The command line:
+
+$0 @ARGV
+
+contains redirections, so should be run from a command prompt window.
+In general, it's a good idea to always run xmltv from a command prompt
+so that you can see any errors and warnings produced.
+END
+      ;
+    sleep 10;
+    exit 1;
+}
+
 #
 # get/check time zone
 #
@@ -41,6 +59,13 @@ print STDERR "Timezone is $ENV{TZ}\n";
 
 $cmd = shift || "";
 
+# --version (and abbreviations thereof)
+my $VERSION = '0.5.28';
+if (index('--version', $cmd) == 0 and length $cmd >= 3) {
+    print "xmltv $VERSION\n";
+    exit;
+}
+
 #
 # check for tv_grab_nz
 #
@@ -59,8 +84,7 @@ END
 #
 # some programs use a "share" directory
 #
-if ($cmd eq 'tv_grab_uk'
- or $cmd eq 'tv_grab_uk_rt'
+if ($cmd eq 'tv_grab_uk_rt'
  or $cmd eq 'tv_grab_it'
  or $cmd eq 'tv_grab_nl'
  )
@@ -78,7 +102,7 @@ if ($cmd eq 'tv_grab_uk'
         print "adding '--share=$dir'\n";
         push @ARGV,"--share",$dir;
     }
-} 
+}
 
 #
 # scan through attached files and execute program if found
